@@ -246,8 +246,8 @@ unsigned char *swf_tag_jpeg_get_jpeg_data(void *detail,
     if (swf_tag_jpeg->image_id != image_id) {
         return NULL;
     }
-    *length = swf_tag_jpeg->jpeg_data_len;
-    if (*length == 0) {
+    if (swf_tag_jpeg->jpeg_data_len == 0) {
+        fprintf(stderr, "swf_tag_jpeg_get_jpeg_data: swf_tag_jpeg->jpeg_data_len\n");
         return NULL;
     }
     data = jpegconv_swf2std(swf_tag_jpeg->jpeg_data,
