@@ -50,16 +50,23 @@ swf_tag_lossless_create_detail(unsigned char *data,
     swf_tag_lossless->height = bitstream_getbytesLE(bs, 2);
     if (swf_tag_lossless->format == 3) {
         unsigned long indices_len;
-        swf_tag_lossless->colormap_count = bitstream_getbyte(bs) + 1; /* XXX */
+        int bytes_per_color;
+        swf_tag_lossless->colormap_count = bitstream_getbyte(bs) + 1;
         indices_len = ((swf_tag_lossless->width + 3) & -4) * swf_tag_lossless->height;
-        origsize = 4 * swf_tag_lossless->colormap_count + indices_len;
+        if (tag->tag == 20) { // Lossless => rgb (3 bytes)
+            bytes_per_color = 3;
+        } else { // Lossless2 => rgba (4 bytes)
+            bytes_per_color = 4;
+        }
+        origsize = bytes_per_color * swf_tag_lossless->colormap_count + indices_len;
         tmp_buff = malloc(origsize);
         offset = bitstream_getbytepos(bs);
         old_buff = bitstream_buffer(bs, offset);
         old_size = bitstream_length(bs) - offset;
         result = uncompress(tmp_buff, &origsize, old_buff, old_size);
-        if (indices_len != origsize - 4 * swf_tag_lossless->colormap_count) {
-            fprintf(stderr, "swf_tag_lossless_create_detail: indices_len != origsize - 4 * swf_tag_lossless->colormap_count at line(%d)\n", __LINE__);
+        if (indices_len != origsize - bytes_per_color * swf_tag_lossless->colormap_count) {
+            fprintf(stderr, "swf_tag_lossless_create_detail: indices_len != origsize - %d * swf_tag_lossless->colormap_count at line(%d)\n",
+                    bytes_per_color, __LINE__);
             free(tmp_buff);
             bitstream_close(bs);
             return NULL;
@@ -100,7 +107,7 @@ swf_tag_lossless_create_detail(unsigned char *data,
     } else { // format != 3
         unsigned long bitmap_count;
         bitmap_count = swf_tag_lossless->width * swf_tag_lossless->height;
-        origsize = 4 * bitmap_count; // xrgb or argb
+        origsize = 4 * bitmap_count; // xrgb or argb (4 bytes)
         tmp_buff = malloc(origsize);
         offset = bitstream_getbytepos(bs);
         old_buff = bitstream_buffer(bs, offset);
@@ -198,7 +205,8 @@ swf_tag_lossless_output_detail(void *detail, unsigned long *length,
             }
         }
         indices_len = ((swf_tag_lossless->width + 3) & -4) * swf_tag_lossless->height;
-        old_buff = bitstream_steal(bs2, &old_size);
+        old_buff = bitstream_buffer(bs2, 0);
+        old_size = bitstream_length(bs2);
         bitstream_close(bs2);
         tmp_buff = malloc(old_size); // too enough size
         compress(tmp_buff, &compsize, old_buff, old_size);
@@ -220,7 +228,8 @@ swf_tag_lossless_output_detail(void *detail, unsigned long *length,
                 swf_argb_build(bs2, argb);
             }
         }
-        old_buff = bitstream_steal(bs2, &old_size);
+        old_buff = bitstream_buffer(bs2, 0);
+        old_size = bitstream_length(bs2);
         bitstream_close(bs2);
         compsize = old_size; // too enough size
         tmp_buff = malloc(compsize);
